@@ -5,9 +5,11 @@
 #include "../Common/Common.h"
 
 #include "ColourIO.h"
+#include <cstring>
+
 using namespace Dasher;
 using namespace std;
-using namespace expat;
+//using namespace expat;
 
 // Track memory leaks on Windows to the line that new'd the memory
 #ifdef _WIN32
@@ -19,7 +21,9 @@ static char THIS_FILE[] = __FILE__;
 #endif
 #endif
 
-CColourIO::CColourIO(string SystemLocation, string UserLocation, vector <string >Filenames)
+// TODO: Share information with AlphIO class?
+
+CColourIO::CColourIO(std::string SystemLocation, std::string UserLocation, std::vector<std::string> Filenames)
 :BlankInfo(), SystemLocation(SystemLocation), UserLocation(UserLocation), Filenames(Filenames), LoadMutable(false), CData("") {
   CreateDefault();
 
@@ -115,7 +119,7 @@ void CColourIO::Save(const std::string &ColourID) {
   // overhead doesn't seem to matter and it makes things much easier.
 
   FILE *Output;
-  string Filename = UserLocation + "colours.xml";
+  std::string Filename = UserLocation + "colours.xml";
   if((Output = fopen(Filename.c_str(), "w")) == (FILE *) 0) {
     // could not open file
   }
@@ -128,6 +132,8 @@ void CColourIO::Save(const std::string &ColourID) {
 }
 
 void CColourIO::CreateDefault() {
+  // TODO: Urgh - replace with a table
+  
   ColourInfo & Default = Colours["Default"];
   Default.ColourID = "Default";
   Default.Mutable = false;
@@ -866,7 +872,7 @@ void CColourIO::CreateDefault() {
 void CColourIO::XML_Escape(std::string *Text, bool Attribute) {
   // The XML "W3C Recommendation" is here: http://www.w3.org/TR/REC-xml
 
-  string & Input = *Text;       // Makes syntax less fiddly below
+  std::string & Input = *Text;       // Makes syntax less fiddly below
 
   for(unsigned int i = 0; i < Text->size(); i++) {
     // & and < need escaping in XML. In one rare circumstance >
