@@ -1,4 +1,6 @@
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #ifdef WITH_GCONF
 #include <gconf/gconf.h>
@@ -6,6 +8,7 @@
 #include <gconf/gconf-enum-types.h>
 #endif
 
+#include <cstring>
 #include "DasherAppSettings.h"
 #include "../Common/AppSettingsData.h"
 
@@ -18,6 +21,12 @@
 
 // FIXME - should really do something to make this a singleton class
 
+// TODO: Rename this file to fit in with naming conventions
+
+// TODO: Bring this into the widget
+static GtkWidget *pDasherWidget = NULL;
+
+
 struct _DasherAppSettingsPrivate {
 #ifdef WITH_GCONF
   // GConf interface
@@ -100,6 +109,8 @@ static void dasher_app_settings_destroy(GObject *pObject) {
 void dasher_app_settings_set_widget(DasherAppSettings *pSelf, GtkDasherControl *pWidget) {
   DasherAppSettingsPrivate *pPrivate = (DasherAppSettingsPrivate*)(pSelf->private_data);
 
+  pDasherWidget = GTK_WIDGET(pWidget);
+
   pPrivate->pWidget = pWidget;
   pPrivate->bWidgetSet = TRUE;
 }
@@ -111,7 +122,7 @@ static void dasher_app_settings_init_gconf(DasherAppSettings *pSelf, int argc, c
   GError *pGConfError;
 
   if(!gconf_init(argc, argv, &pGConfError))
-    g_error("Failed to initilaise gconf: %s", pGConfError->message);
+    g_error("Failed to initialise gconf: %s", pGConfError->message);
   
   // FIXME - apparently there's a function gnome_gconf_get_client - maybe we should use this if building with gnome
     pPrivate->pGConfClient = gconf_client_get_default();
@@ -222,7 +233,7 @@ void dasher_app_settings_reset(DasherAppSettings *pSelf, int iParameter) {
     return;
   }
   else {
-    pre_parameter_notification(0, iParameter, 0);
+    //    pre_parameter_notification(0, iParameter, 0);
     
     if(iParameter < END_OF_APP_BPS)
       app_boolparamtable[ iParameter - FIRST_APP_BP ].value = app_boolparamtable[ iParameter - FIRST_APP_BP ].bDefaultValue;
@@ -256,15 +267,14 @@ bool dasher_app_settings_get_bool(DasherAppSettings *pSelf, int iParameter) {
 void dasher_app_settings_set_bool(DasherAppSettings *pSelf, int iParameter, bool bValue) {
   DasherAppSettingsPrivate *pPrivate = (DasherAppSettingsPrivate *)(pSelf->private_data);
 
-  if( iParameter < END_OF_BPS )
+  if( iParameter < END_OF_BPS ) {
     if(pPrivate->bWidgetSet) {
       gtk_dasher_control_set_parameter_bool(GTK_DASHER_CONTROL(pDasherWidget), iParameter, bValue);
     }
+  }
   else {
     if(dasher_app_settings_get_bool(pSelf, iParameter) == bValue)
       return; // Don't attempt to change to the existing value
-   
-    pre_parameter_notification(0, iParameter, 0);
 
     app_boolparamtable[ iParameter - FIRST_APP_BP ].value = bValue;
 #ifdef WITH_GCONF    
@@ -276,6 +286,9 @@ void dasher_app_settings_set_bool(DasherAppSettings *pSelf, int iParameter, bool
       
       GError *pGConfError = NULL;
       gconf_client_set_bool(pPrivate->pGConfClient, szName, bValue, &pGConfError);
+
+      if(pGConfError)
+	g_message("Error");
     }
 #endif
 
@@ -308,7 +321,7 @@ void dasher_app_settings_set_long(DasherAppSettings *pSelf, int iParameter, gint
     if(dasher_app_settings_get_long(pSelf, iParameter) == iValue)
       return; // Don't attempt to change to the existing value
     
-    pre_parameter_notification(0, iParameter, 0);
+    //    pre_parameter_notification(0, iParameter, 0);
 
     app_longparamtable[ iParameter - FIRST_APP_LP ].value = iValue;
 
@@ -388,7 +401,7 @@ void dasher_app_settings_set_string(DasherAppSettings *pSelf, int iParameter, co
     if(!strcmp(dasher_app_settings_get_string(pSelf, iParameter), szValue))
       return; // Don't attempt to change to the existing value
 
-    pre_parameter_notification(0, iParameter, 0);
+    //    pre_parameter_notification(0, iParameter, 0);
     
     delete[] app_stringparamtable[ iParameter - FIRST_APP_SP ].value;
     
@@ -481,3 +494,88 @@ void dasher_app_settings_launch_advanced(DasherAppSettings *pSelf) {
     g_warning("Could not launch gconf-editor: %s", pError->message);
   }
 }
+
+void dasher_app_settings_set_widget(DasherAppSettings *pSelf, GtkWidget *pWidget) {
+  pDasherWidget = pWidget;
+}
+
+GArray *dasher_app_settings_get_allowed_values(DasherAppSettings *pSelf, int iParameter) {
+  return gtk_dasher_control_get_allowed_values(GTK_DASHER_CONTROL(pDasherWidget), iParameter);
+}
+
+gboolean dasher_app_settings_get_module_settings(DasherAppSettings *pSelf, const gchar *szValue, SModuleSettings **pSettings, gint *iCount) {
+  return gtk_dasher_control_get_module_settings(GTK_DASHER_CONTROL(pDasherWidget), szValue, pSettings, iCount);
+}
+
+// Set the option szKey to szValue.  Return NULL if everything worked, a
+// (literal) error string for unrecognized or illegal values.
+const gchar *
+dasher_app_settings_cl_set(DasherAppSettings *pSelf, const gchar *szKey, const gchar *szValue) {
+
+  for(int i(0); i < NUM_OF_APP_BPS; ++i ) {
+    if(!strcmp(app_boolparamtable[i].regName, szKey)) {
+      
+      if(!strcmp(szValue, "1") || !strcmp(szValue, _("true")))
+        dasher_app_settings_set_bool(pSelf, app_boolparamtable[i].key, true);
+      else if(!strcmp(szValue, "0") || !strcmp(szValue, _("false")))
+        dasher_app_settings_set_bool(pSelf, app_boolparamtable[i].key, false);
+      else
+        return _("boolean value must be specified as 'true' or 'false'.");
+      return 0;
+    }
+  }
+
+  for(int i(0); i < NUM_OF_APP_LPS; ++i ) {
+    if(!strcmp(app_longparamtable[i].regName, szKey)) {
+      dasher_app_settings_set_long(pSelf, app_longparamtable[i].key, atoi(szValue));
+      return 0;
+    }
+  }
+
+  for(int i(0); i < NUM_OF_APP_SPS; ++i ) {
+    if(!strcmp(app_stringparamtable[i].regName, szKey)) {
+      dasher_app_settings_set_string(pSelf, app_stringparamtable[i].key, szValue);
+      return 0;
+    }
+  }  
+
+  return gtk_dasher_control_cl_set(GTK_DASHER_CONTROL(pDasherWidget), szKey, szValue);
+}
+
+
+void option_help()
+{
+  g_print("\n");
+  g_print("%-30s %-12s  %s\n", _("Boolean parameters"), _("Default"), _("Description"));
+  g_print("%-30s %-12s  %s\n", "------------------------------", "------------", "------------------------------");
+  for(unsigned int i=0; i < sizeof(app_boolparamtable)/sizeof(app_boolparamtable[0]); ++i) {
+    g_print("%-30s %-12s  %s\n", app_boolparamtable[i].regName, (app_boolparamtable[i].bDefaultValue ? _("true") : _("false")), app_boolparamtable[i].humanReadable);
+  }
+
+  for(unsigned int i = 0; i < sizeof(boolparamtable)/sizeof(boolparamtable[0]); i++) {
+    g_print("%-30s %-12s  %s\n", boolparamtable[i].regName, (boolparamtable[i].defaultValue ? _("true") : _("false")), boolparamtable[i].humanReadable);
+  }
+
+  g_print("\n");
+  g_print("%-30s %-12s  %s\n", _("Integer parameters"), _("Default"), _("Description"));
+  g_print("%-30s %-12s  %s\n", "------------------------------", "------------", "------------------------------");
+  for(unsigned int i=0; i < sizeof(app_longparamtable)/sizeof(app_longparamtable[0]); ++i) {
+    g_print("%-30s %12li  %s\n", app_longparamtable[i].regName, app_longparamtable[i].iDefaultValue, app_longparamtable[i].humanReadable);
+  }
+
+  for(unsigned int i = 0; i < sizeof(longparamtable)/sizeof(longparamtable[0]); i++) {
+    g_print("%-30s %12li  %s\n", longparamtable[i].regName, longparamtable[i].defaultValue, longparamtable[i].humanReadable);
+  }
+
+  g_print("\n");
+  g_print("%-30s %-12s  %s\n", _("String parameters"), _("Default"), _("Description"));
+  g_print("%-30s %-12s  %s\n", "------------------------------", "------------", "------------------------------");
+  for(unsigned int i=0; i < sizeof(app_stringparamtable)/sizeof(app_stringparamtable[0]); ++i) {
+    g_print("%-30s %-12s  %s\n", app_stringparamtable[i].regName, app_stringparamtable[i].szDefaultValue, app_stringparamtable[i].humanReadable);
+  }
+
+  for(unsigned int i = 0; i < sizeof(stringparamtable)/sizeof(stringparamtable[0]); i++) {
+    g_print("%-30s %-12s  %s\n", stringparamtable[i].regName, stringparamtable[i].defaultValue, stringparamtable[i].humanReadable);
+  }
+
+}
