@@ -1,7 +1,9 @@
 #ifndef __dashercontrol_h__
 #define __dashercontrol_h__
 
-#include "../../config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include "PangoCache.h"
 #include "Canvas.h"
@@ -116,17 +118,6 @@ public:
 
   GArray *GetAllowedValues(int iParameter);
 
-  /// 
-  /// Load a file and use to train the language model
-  /// \param filename The file to load.
-  ///
-
-  void Train(const gchar * filename) {
-    // TODO: Shouldn't call this directly - need a wrapper function which stats for filesize etc.
-    // Better - allow user to pass a vector of filenames
-    TrainFile(filename,0,0);
-  };
-
   ///
   /// Called by UI needs to signal a new user trial is starting.
   ///
@@ -155,6 +146,8 @@ private:
   ///
 
   void ExternalEventHandler(Dasher::CEvent *pEvent);
+  
+  void GameMessageOut(int message, const void* messagedata);
 
   ///
   /// Notification from CDasherInterface that a parameter has changed
