@@ -18,14 +18,12 @@
 // along with Dasher; if not, write to the Free Software 
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-/* TODO: r4epair gnome libs flags (or get rid of entirely) */
-//#ifdef GNOME_LIBS 
-#include <libgnomevfs/gnome-vfs.h> 
-//#endif
 
 #include "dasher_action_keyboard.h"
 #ifdef WITH_MAEMO
